@@ -1,13 +1,18 @@
-# Copyright 2022-2025 Broadcom.
-# SPDX-License-Identifier: Apache-2
+# Copyright 2022-2026 Broadcom.
+# SPDX-License-Identifier: Apache-2.0
+# mypy: ignore-errors
 """
 The ``relenv fetch`` command.
 """
 
+from __future__ import annotations
+
+import argparse
 import os
 import sys
+from collections.abc import Sequence
 
-from .build import platform_module, platform_versions
+from .build import platform_module
 from .common import (
     CHECK_HOSTS,
     DATA_DIR,
@@ -18,9 +23,12 @@ from .common import (
     get_triplet,
     work_dir,
 )
+from .pyversions import get_default_python_version, resolve_python_version
 
 
-def setup_parser(subparsers):
+def setup_parser(
+    subparsers: argparse._SubParsersAction[argparse.ArgumentParser],
+) -> None:
     """
     Setup the subparser for the ``fetch`` command.
 
@@ -37,17 +45,21 @@ def setup_parser(subparsers):
         type=str,
         help="Architecture to download. [default: %(default)s]",
     )
+    default_version = get_default_python_version()
     subparser.add_argument(
         "--python",
-        default=platform_versions()[0],
-        # Allow fetching of older versions
-        # choices=platform_versions(),
+        default=default_version,
         type=str,
-        help="The python version [default: %(default)s]",
+        help="The python version (e.g., 3.10, 3.13.7) [default: %(default)s]",
     )
 
 
-def fetch(version, triplet, python, check_hosts=CHECK_HOSTS):
+def fetch(
+    version: str,
+    triplet: str,
+    python: str,
+    check_hosts: Sequence[str] = CHECK_HOSTS,
+) -> None:
     """
     Fetch the specified python build.
     """
@@ -67,7 +79,7 @@ def fetch(version, triplet, python, check_hosts=CHECK_HOSTS):
     download_url(url, builddir)
 
 
-def main(args):
+def main(args: argparse.Namespace) -> None:
     """
     The entrypoint into the ``relenv fetch`` command.
 
@@ -76,7 +88,8 @@ def main(args):
     """
     version = os.environ.get("RELENV_FETCH_VERSION", __version__)
     triplet = get_triplet(machine=args.arch)
-    python = args.python
+    # args.python will be the default version or user-specified version
+    python = resolve_python_version(args.python)
     check_hosts = CHECK_HOSTS
     if os.environ.get("RELENV_FETCH_HOST", ""):
         check_hosts = [os.environ["RELENV_FETCH_HOST"]]
